@@ -10,4 +10,11 @@ import sys
 import os
 
 openapi_path = os.path.join(os.path.dirname(__file__), "openapi")
+
+# If ascend SDK is running from sources instead of from an installed package.
+if not os.path.exists(openapi_path):
+  try_openapi_path = os.path.join(os.path.dirname(__file__), "../../bazel-bin/ascend/sdk/cli.runfiles/ascend/ascend/openapi/openapi")
+  if os.path.exists(try_openapi_path):
+    openapi_path = try_openapi_path
+
 sys.path.insert(0, openapi_path)
