@@ -85,6 +85,12 @@ class DataServiceApplier:
     if after_connections:
       after_connections()
 
+    if data_service.data_plane_config:
+      self.client.update_data_service_data_plane_config(data_service.id, data_service.data_plane_config)
+      data_plane_type = data_service.data_service_type if data_service.data_service_type \
+        else data_service.data_plane_config.WhichOneof('data_plane_type')
+      glog.info(f"Apply Data Plane configuration: (ds={data_service.id} type={data_plane_type})")
+
     # Handle dataflows carefully, as we want to first create/apply everything, and only after
     # sweep through and clean up (in reverse order)
     dataflows = dataflows_ordered_by_dependency(data_service.id, data_service.dataflows)
